==> instagram_public_api-0.0.5.tar.gz: lib/models/instaData.dart <==
/// [InstaPost]
class InstaPost {
  final PostType postType;
  final Dimensions dimensions;
  final String displayURL;
  final String postUrl;
  final String thumbnailUrl;
  final Dimensions thumbnailDimensions;
  final PostTime videoDuration;
  final PostUserDetails user;
  InstaPost(
      {this.postType,
      this.postUrl,
      this.dimensions,
      this.displayURL,
      this.videoDuration,
      this.user,
      this.thumbnailDimensions,
      this.thumbnailUrl});
}

/// [PostUserDetails]
class PostUserDetails {
  final String username;
  final String profile_pic_url;
  final bool is_private;
  final bool is_verified;
  final String followers;
  final String posts;

  PostUserDetails(
      {this.username,
      this.profile_pic_url,
      this.is_private,
      this.is_verified,
      this.followers,
      this.posts});
}

/// [PostType]
enum PostType {
  GraphImage,
  GraphVideo,
  GraphSidecar,
}

/// [Dimensions]
class Dimensions {
  final int height;
  final int width;

  Dimensions({this.height, this.width});
}

/// [InstaProfileData]
class InstaProfileData {
  final String username;
  final String profile_pic_url;
  final bool is_private;
  final bool is_verified;
  final String following;
  final String followers;
  final String bio;
  final String external_url;

  InstaProfileData(
      {this.username,
      this.profile_pic_url,
      this.is_private,
      this.is_verified,
      this.following,
      this.followers,
      this.bio,
      this.external_url});
}

/// [PostTime]
class PostTime {
  final String duration;
  final String unit;

  PostTime({this.duration, this.unit});
}

==> instagram_public_api-0.1.1.tar.gz: lib/models/instaData.dart <==
/// [InstaPost]
class InstaPost {
  final PostType postType;
  final Dimensions dimensions;
  final String displayURL;
  final String postUrl;
  final String thumbnailUrl;
  final Dimensions thumbnailDimensions;
  final PostTime videoDuration;
  final PostUserDetails user;
  InstaPost(
      {this.postType,
      this.postUrl,
      this.dimensions,
      this.displayURL,
      this.videoDuration,
      this.user,
      this.thumbnailDimensions,
      this.thumbnailUrl});
}

/// [PostUserDetails]
class PostUserDetails {
  final String username;
  final String profilePicURL;
  final bool isPrivate;
  final bool isVerified;
  final String followers;
  final String posts;

  PostUserDetails(
      {this.username,
      this.profilePicURL,
      this.isPrivate,
      this.isVerified,
      this.followers,
      this.posts});
}

/// [PostType]
enum PostType {
  GraphImage,
  GraphVideo,
  GraphSidecar,
}

/// [Dimensions]
class Dimensions {
  final int height;
  final int width;

  Dimensions({this.height, this.width});
}

/// [InstaProfileData]
class InstaProfileData {
  final String username;
  final String profilePicURL;
  final bool isPrivate;
  final bool isVerified;
  final String following;
  final String followers;
  final String bio;
  final String externalURL;

  InstaProfileData(
      {this.username,
      this.profilePicURL,
      this.isPrivate,
      this.isVerified,
      this.following,
      this.followers,
      this.bio,
      this.externalURL});
}

/// [PostTime]
class PostTime {
  final String duration;
  final String unit;

  PostTime({this.duration, this.unit});
}
